## Example Usage

```python
import time

from pysesame3.auth import WebAPIAuth
from pysesame3.lock import CHSesame2


def main():
    auth = WebAPIAuth(apikey="fakeapikey")

    """
    By decoding the QR code generated by the official iOS/Android app,
    you can get the information you need.

    https://sesame-qr-reader.vercel.app/
    """
    your_key_uuid = "fakeuuid"
    your_key_secret = "fakesecret"

    device = CHSesame2(
        authenticator=auth, device_uuid=your_key_uuid, secret_key=your_key_secret
    )

    print((str(device.mechStatus)))
    # => CHSesame2MechStatus(Battery=100% (6.08V), isInLockRange=True, isInUnlockRange=False, Position=-10)

    """
    The `history_tag` can be set when locking and unlocking (default = `pysesame3`).
    This tag will be stored in the history as the name (tag) of the key that unlocked or locked the door.
    It will be more understandable when auditing the key operation using APIs and the apps.
    """
    device.unlock(history_tag="My Script")

    """
    `mechStatus` always gets the latest status from the cloud.
    Therefore, **just after** locking or unlocking the door, the status such as `isInLockRange` will not be updated.
    """
    time.sleep(5)

    print((str(device.mechStatus)))
    # => CHSesame2MechStatus(Battery=100% (6.09V), isInLockRange=False, isInUnlockRange=True, Position=241)

    device.toggle()
    time.sleep(5)

    print((str(device.mechStatus)))
    # => CHSesame2MechStatus(Battery=100% (6.09V), isInLockRange=True, isInUnlockRange=False, Position=25)


if __name__ == "__main__":
    main()

```
